streamdeck_flutter library

Classes

ActionFrame
ActionInfo
ApplicationDidLaunchEvent
ApplicationDidTerminateEvent
ApplicationPayload
Client
WebSocket client for the Elgato Stream Deck plugin protocol.
CommonReceivedEvent
Received event with action context (action, context, device).
ConnectionInfo
ContextPayload
Coordinates
DeviceApplication
DeviceColors
DeviceData
DeviceDidChangeEvent
Stream Deck 7.0+: a device's properties changed.
DeviceDidConnectEvent
DeviceDidDisconnectEvent
DeviceInfo
DevicePlugin
DeviceSize
Dial
DialDownEvent
DialPressPayload
DialRotateEvent
DialRotatePayload
DialUpEvent
DidReceiveDeepLinkEvent
A deep-link URL was received for this plugin.
DidReceiveGlobalSettingsEvent
DidReceiveResourcesEvent
Stream Deck 7.1+: resource images resolved for an action.
DidReceiveSecretsEvent
Secrets (e.g. API keys) delivered to the plugin.
DidReceiveSettingsEvent
FpsOverlay
FrameTiming
HeadlessBinding
A custom WidgetsFlutterBinding that keeps the frame pipeline alive on hidden macOS windows.
KeyDownEvent
Keypad
KeyPayload
KeyUpEvent
Layout
Physical layout for a Stream Deck device.
Manifest
ManifestAction
ManifestApplicationsToMonitor
ManifestEncoder
ManifestOS
ManifestProfile
ManifestSoftware
ManifestState
ManifestTriggerDescription
PropertyInspectorDidAppearEvent
PropertyInspectorDidDisappearEvent
Raster
SdEvent
Base class for all Stream Deck WebSocket events.
SendToPluginEvent
StreamDeck
StreamDeckAction
StreamDeckPlugin
SystemDidWakeUpEvent
TitleParameters
TitleParametersDidChangeEvent
TitleParametersDidChangePayload
TouchTapEvent
TouchTapPayload
WillDisappearEvent

Enums

ActionType
Connection
Connection state of the Stream Deck WebSocket.
ControllerType
DeviceType

Mixins

StreamDeckMixin<S extends StatefulWidget>

Extensions

ActionFramePatterns on ActionFrame
Adds pattern-matching-related methods to ActionFrame.
ActionInfoPatterns on ActionInfo
Adds pattern-matching-related methods to ActionInfo.
ApplicationDidLaunchEventPatterns on ApplicationDidLaunchEvent
Adds pattern-matching-related methods to ApplicationDidLaunchEvent.
ApplicationDidTerminateEventPatterns on ApplicationDidTerminateEvent
Adds pattern-matching-related methods to ApplicationDidTerminateEvent.
ApplicationPayloadPatterns on ApplicationPayload
Adds pattern-matching-related methods to ApplicationPayload.
ConnectionInfoPatterns on ConnectionInfo
Adds pattern-matching-related methods to ConnectionInfo.
ContextPayloadPatterns on ContextPayload
Adds pattern-matching-related methods to ContextPayload.
CoordinatesPatterns on Coordinates
Adds pattern-matching-related methods to Coordinates.
DeviceApplicationPatterns on DeviceApplication
Adds pattern-matching-related methods to DeviceApplication.
DeviceColorsPatterns on DeviceColors
Adds pattern-matching-related methods to DeviceColors.
DeviceDataPatterns on DeviceData
Adds pattern-matching-related methods to DeviceData.
DeviceDidChangeEventPatterns on DeviceDidChangeEvent
Adds pattern-matching-related methods to DeviceDidChangeEvent.
DeviceDidConnectEventPatterns on DeviceDidConnectEvent
Adds pattern-matching-related methods to DeviceDidConnectEvent.
DeviceDidDisconnectEventPatterns on DeviceDidDisconnectEvent
Adds pattern-matching-related methods to DeviceDidDisconnectEvent.
DeviceInfoPatterns on DeviceInfo
Adds pattern-matching-related methods to DeviceInfo.
DevicePluginPatterns on DevicePlugin
Adds pattern-matching-related methods to DevicePlugin.
DeviceSizePatterns on DeviceSize
Adds pattern-matching-related methods to DeviceSize.
DialDownEventPatterns on DialDownEvent
Adds pattern-matching-related methods to DialDownEvent.
DialPressPayloadPatterns on DialPressPayload
Adds pattern-matching-related methods to DialPressPayload.
DialRotateEventPatterns on DialRotateEvent
Adds pattern-matching-related methods to DialRotateEvent.
DialRotatePayloadPatterns on DialRotatePayload
Adds pattern-matching-related methods to DialRotatePayload.
DialUpEventPatterns on DialUpEvent
Adds pattern-matching-related methods to DialUpEvent.
DidReceiveDeepLinkEventPatterns on DidReceiveDeepLinkEvent
Adds pattern-matching-related methods to DidReceiveDeepLinkEvent.
DidReceiveGlobalSettingsEventPatterns on DidReceiveGlobalSettingsEvent
Adds pattern-matching-related methods to DidReceiveGlobalSettingsEvent.
DidReceiveResourcesEventPatterns on DidReceiveResourcesEvent
Adds pattern-matching-related methods to DidReceiveResourcesEvent.
DidReceiveSecretsEventPatterns on DidReceiveSecretsEvent
Adds pattern-matching-related methods to DidReceiveSecretsEvent.
DidReceiveSettingsEventPatterns on DidReceiveSettingsEvent
Adds pattern-matching-related methods to DidReceiveSettingsEvent.
FrameTimingPatterns on FrameTiming
Adds pattern-matching-related methods to FrameTiming.
KeyDownEventPatterns on KeyDownEvent
Adds pattern-matching-related methods to KeyDownEvent.
KeyPayloadPatterns on KeyPayload
Adds pattern-matching-related methods to KeyPayload.
KeyUpEventPatterns on KeyUpEvent
Adds pattern-matching-related methods to KeyUpEvent.
ManifestActionPatterns on ManifestAction
Adds pattern-matching-related methods to ManifestAction.
ManifestApplicationsToMonitorPatterns on ManifestApplicationsToMonitor
Adds pattern-matching-related methods to ManifestApplicationsToMonitor.
ManifestEncoderPatterns on ManifestEncoder
Adds pattern-matching-related methods to ManifestEncoder.
ManifestOSPatterns on ManifestOS
Adds pattern-matching-related methods to ManifestOS.
ManifestPatterns on Manifest
Adds pattern-matching-related methods to Manifest.
ManifestProfilePatterns on ManifestProfile
Adds pattern-matching-related methods to ManifestProfile.
ManifestSoftwarePatterns on ManifestSoftware
Adds pattern-matching-related methods to ManifestSoftware.
ManifestStatePatterns on ManifestState
Adds pattern-matching-related methods to ManifestState.
ManifestTriggerDescriptionPatterns on ManifestTriggerDescription
Adds pattern-matching-related methods to ManifestTriggerDescription.
PropertyInspectorDidAppearEventPatterns on PropertyInspectorDidAppearEvent
Adds pattern-matching-related methods to PropertyInspectorDidAppearEvent.
PropertyInspectorDidDisappearEventPatterns on PropertyInspectorDidDisappearEvent
Adds pattern-matching-related methods to PropertyInspectorDidDisappearEvent.
SendToPluginEventPatterns on SendToPluginEvent
Adds pattern-matching-related methods to SendToPluginEvent.
SystemDidWakeUpEventPatterns on SystemDidWakeUpEvent
Adds pattern-matching-related methods to SystemDidWakeUpEvent.
TitleParametersDidChangeEventPatterns on TitleParametersDidChangeEvent
Adds pattern-matching-related methods to TitleParametersDidChangeEvent.
TitleParametersDidChangePayloadPatterns on TitleParametersDidChangePayload
Adds pattern-matching-related methods to TitleParametersDidChangePayload.
TitleParametersPatterns on TitleParameters
Adds pattern-matching-related methods to TitleParameters.
TouchTapEventPatterns on TouchTapEvent
Adds pattern-matching-related methods to TouchTapEvent.
TouchTapPayloadPatterns on TouchTapPayload
Adds pattern-matching-related methods to TouchTapPayload.
WillDisappearEventPatterns on WillDisappearEvent
Adds pattern-matching-related methods to WillDisappearEvent.

Functions

setupLogging() → void