ContextPayload class sealed

Available extensions
Annotations
  • @freezed

Constructors

ContextPayload({@Default.new({}) Map<String, Object?> settings, required Coordinates coordinates, @Default.new(0) int state, @Default.new(false) bool isInMultiAction, ActionType? controller, @Default.new({}) Map<String, String> resources})
const
factory
ContextPayload.fromJson(Map<String, dynamic> json)
factory

Properties

controller ActionType?
no setterinherited
coordinates Coordinates
no setterinherited
copyWith → $ContextPayloadCopyWith<ContextPayload>
Create a copy of ContextPayload with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isInMultiAction bool
no setterinherited
resources Map<String, String>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings Map<String, Object?>
no setterinherited
state int
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ContextPayload value)) → TResult

Available on ContextPayload, provided by the ContextPayloadPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ContextPayload value)?) → TResult?

Available on ContextPayload, provided by the ContextPayloadPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ContextPayload value)?, {required TResult orElse()}) → TResult

Available on ContextPayload, provided by the ContextPayloadPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(Map<String, Object?> settings, Coordinates coordinates, int state, bool isInMultiAction, ActionType? controller, Map<String, String> resources)?, {required TResult orElse()}) → TResult

Available on ContextPayload, provided by the ContextPayloadPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setting<T>(String key, [T? defaultValue]) → T?
Typed settings accessor with optional default.
toJson() Map<String, dynamic>
Serializes this ContextPayload to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(Map<String, Object?> settings, Coordinates coordinates, int state, bool isInMultiAction, ActionType? controller, Map<String, String> resources)) → TResult

Available on ContextPayload, provided by the ContextPayloadPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(Map<String, Object?> settings, Coordinates coordinates, int state, bool isInMultiAction, ActionType? controller, Map<String, String> resources)?) → TResult?

Available on ContextPayload, provided by the ContextPayloadPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited