DialPressPayload class sealed
- Available extensions
- Annotations
-
- @freezed
Constructors
-
DialPressPayload({@Default.new({}) Map<
String, Object?> settings, required Coordinates coordinates, @Default.new(false) bool pressed, String? controller}) -
constfactory
-
DialPressPayload.fromJson(Map<
String, dynamic> json) -
factory
Properties
- controller → String?
-
no setterinherited
- coordinates → Coordinates
-
no setterinherited
-
copyWith
→ $DialPressPayloadCopyWith<
DialPressPayload> -
Create a copy of DialPressPayload
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- pressed → bool
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
settings
→ Map<
String, Object?> -
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_DialPressPayload value)) → TResult -
Available on DialPressPayload, provided by the DialPressPayloadPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_DialPressPayload value)?) → TResult? -
Available on DialPressPayload, provided by the DialPressPayloadPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_DialPressPayload value)?, {required TResult orElse()}) → TResult -
Available on DialPressPayload, provided by the DialPressPayloadPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(Map< String, Object?> settings, Coordinates coordinates, bool pressed, String? controller)?, {required TResult orElse()}) → TResult -
Available on DialPressPayload, provided by the DialPressPayloadPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this DialPressPayload to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(Map< String, Object?> settings, Coordinates coordinates, bool pressed, String? controller)) → TResult -
Available on DialPressPayload, provided by the DialPressPayloadPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(Map< String, Object?> settings, Coordinates coordinates, bool pressed, String? controller)?) → TResult? -
Available on DialPressPayload, provided by the DialPressPayloadPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited