ManifestProfile class sealed

Available extensions
Annotations
  • @freezed

Constructors

ManifestProfile({@JsonKey.new(name: 'Name') required String name, @JsonKey.new(name: 'DeviceType') required int deviceType, @JsonKey.new(name: 'Readonly') @Default.new(false) bool readonly, @JsonKey.new(name: 'DontAutoSwitchWhenInstalled') @Default.new(false) bool dontAutoSwitchWhenInstalled, @JsonKey.new(name: 'AutoInstall') @Default.new(false) bool autoInstall})
const
factory
ManifestProfile.fromJson(Map<String, dynamic> json)
factory

Properties

autoInstall bool
no setterinherited
copyWith → $ManifestProfileCopyWith<ManifestProfile>
Create a copy of ManifestProfile with the given fields replaced by the non-null parameter values.
no setterinherited
deviceType int
no setterinherited
dontAutoSwitchWhenInstalled bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
name String
no setterinherited
readonly bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ManifestProfile value)) → TResult

Available on ManifestProfile, provided by the ManifestProfilePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ManifestProfile value)?) → TResult?

Available on ManifestProfile, provided by the ManifestProfilePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ManifestProfile value)?, {required TResult orElse()}) → TResult

Available on ManifestProfile, provided by the ManifestProfilePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String name, int deviceType, bool readonly, bool dontAutoSwitchWhenInstalled, bool autoInstall)?, {required TResult orElse()}) → TResult

Available on ManifestProfile, provided by the ManifestProfilePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ManifestProfile to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String name, int deviceType, bool readonly, bool dontAutoSwitchWhenInstalled, bool autoInstall)) → TResult

Available on ManifestProfile, provided by the ManifestProfilePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String name, int deviceType, bool readonly, bool dontAutoSwitchWhenInstalled, bool autoInstall)?) → TResult?

Available on ManifestProfile, provided by the ManifestProfilePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited