ManifestState class sealed

Available extensions
Annotations
  • @freezed

Constructors

ManifestState({@JsonKey.new(name: 'Image') required String image, @JsonKey.new(name: 'MultiActionImage') String? multiActionImage, @JsonKey.new(name: 'Name') String? name, @JsonKey.new(name: 'Title') String? title, @JsonKey.new(name: 'ShowTitle') String? showTitle, @JsonKey.new(name: 'TitleColor') String? titleColor, @JsonKey.new(name: 'TitleAlignment') String? titleAlignment, @JsonKey.new(name: 'FontFamily') String? fontFamily, @JsonKey.new(name: 'FontStyle') String? fontStyle, @JsonKey.new(name: 'FontSize') String? fontSize, @JsonKey.new(name: 'FontUnderline') @Default.new(false) bool fontUnderline})
const
factory
ManifestState.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $ManifestStateCopyWith<ManifestState>
Create a copy of ManifestState with the given fields replaced by the non-null parameter values.
no setterinherited
fontFamily String?
no setterinherited
fontSize String?
no setterinherited
fontStyle String?
no setterinherited
fontUnderline bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
image String
no setterinherited
multiActionImage String?
no setterinherited
name String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showTitle String?
no setterinherited
title String?
no setterinherited
titleAlignment String?
no setterinherited
titleColor String?
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_ManifestState value)) → TResult

Available on ManifestState, provided by the ManifestStatePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_ManifestState value)?) → TResult?

Available on ManifestState, provided by the ManifestStatePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_ManifestState value)?, {required TResult orElse()}) → TResult

Available on ManifestState, provided by the ManifestStatePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String image, String? multiActionImage, String? name, String? title, String? showTitle, String? titleColor, String? titleAlignment, String? fontFamily, String? fontStyle, String? fontSize, bool fontUnderline)?, {required TResult orElse()}) → TResult

Available on ManifestState, provided by the ManifestStatePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ManifestState to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String image, String? multiActionImage, String? name, String? title, String? showTitle, String? titleColor, String? titleAlignment, String? fontFamily, String? fontStyle, String? fontSize, bool fontUnderline)) → TResult

Available on ManifestState, provided by the ManifestStatePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String image, String? multiActionImage, String? name, String? title, String? showTitle, String? titleColor, String? titleAlignment, String? fontFamily, String? fontStyle, String? fontSize, bool fontUnderline)?) → TResult?

Available on ManifestState, provided by the ManifestStatePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited