Raster class

Constructors

Raster({int maxFps = 10})

Properties

frames Stream<ActionFrame>
no setter
hashCode int
The hash code for this object.
no setterinherited
maxFps int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
markAllDirty() → void
markDirty(String context) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerAction(ActionInfo action, GlobalKey<State<StatefulWidget>> boundary) → void
start() → void
startAnimating(String context) → void
stop() → void
stopAnimating(String context) → void
toString() String
A string representation of this object.
inherited
unregisterAction(String context) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

hashBytes(Uint8List bytes) int
FNV-1a hash for change detection.