Raster class
Properties
-
frames
→ Stream<
ActionFrame> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxFps → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
markAllDirty(
) → void -
markDirty(
String context) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerAction(
ActionInfo action, GlobalKey< State< boundary) → voidStatefulWidget> > -
start(
) → void -
startAnimating(
String context) → void -
stop(
) → void -
stopAnimating(
String context) → void -
toString(
) → String -
A string representation of this object.
inherited
-
unregisterAction(
String context) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited